@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2015-10-03'; # DATE
-our $VERSION = '1.35'; # VERSION
+our $DATE = '2015-10-20'; # DATE
+our $VERSION = '1.36'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1063,15 +1063,15 @@ sub parse_cmdline_src {
                 my $is_ary = $type eq 'array';
                 if ($src eq 'stdin_line' && !exists($r->{args}{$an})) {
                     require Perinci::Object;
-                    require Term::ReadKey;
+                    my $term_readkey_available = eval { require Term::ReadKey; 1 };
                     my $prompt = Perinci::Object::rimeta($as)->langprop('cmdline_prompt') //
                         sprintf($self->default_prompt_template, $an);
                     print $prompt;
                     my $iactive = (-t STDOUT);
                     Term::ReadKey::ReadMode('noecho')
-                          if $iactive && $as->{is_password};
+                          if $term_readkey_available && $iactive && $as->{is_password};
                     chomp($r->{args}{$an} = <STDIN>);
-                    do { print "\n"; Term::ReadKey::ReadMode(0) }
+                    do { print "\n"; Term::ReadKey::ReadMode(0) if $term_readkey_available }
                         if $iactive && $as->{is_password};
                     $r->{args}{"-cmdline_src_$an"} = 'stdin_line';
                 } elsif ($src eq 'stdin' || $src eq 'file' &&
@@ -1399,7 +1399,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.35 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-10-03.
+This document describes version 1.36 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-10-20.
 
 =head1 DESCRIPTION
 
